<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Thomas Nygreen <nygreen@gmail.com>
 * @author Arild Burud <arildb@met.no>
 * @author Torkill Bruland <torkar-b@online.no>
 * @author Rune M. Andersen <rune.andersen@gmail.com>
 * @author Jakob Vad Nielsen (me@jakobnielsen.net)
 * @author Kjell Tore Næsgaard <kjell.t.nasgaard@ntnu.no>
 * @author Knut Staring <knutst@gmail.com>
 * @author Lisa Ditlefsen <lisa@vervesearch.com>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
 * @author Rune Rasmussen syntaxerror.no@gmail.com
 * @author Jon Bøe <jonmagneboe@hotmail.com>
 * @author Egil Hansen <egil@rosetta.no>
 */
$lang['menu']                  = 'Behandle programtillegg';
$lang['download']              = 'Last ned og installer et programtillegg';
$lang['manage']                = 'Installerte programtillegg';
$lang['btn_info']              = 'informasjon';
$lang['btn_update']            = 'oppdater';
$lang['btn_delete']            = 'slett';
$lang['btn_settings']          = 'innstillinger';
$lang['btn_download']          = 'Last ned';
$lang['btn_enable']            = 'Lagre';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installert:';
$lang['lastupdate']            = 'Sist oppdatert:';
$lang['source']                = 'Kilde:';
$lang['unknown']               = 'ukjent';
$lang['updating']              = 'Oppdaterer ...';
$lang['updated']               = 'Tillegget %s er oppdatert';
$lang['updates']               = 'Følgende programtillegg har blitt oppdatert';
$lang['update_none']           = 'Ingen oppdateringer funnet.';
$lang['deleting']              = 'Sletter ...';
$lang['deleted']               = 'Tillegget %s ble slettet.';
$lang['downloading']           = 'Laster ned ...';
$lang['downloaded']            = 'Tillegget %s ble installert';
$lang['downloads']             = 'De følgende tilleggene ble installert';
$lang['download_none']         = 'Ingen tillegg funnet, eller det har vært et ukjent problem under nedlasting og installering.';
$lang['plugin']                = 'Tillegg:';
$lang['components']            = 'Komponenter';
$lang['noinfo']                = 'Tillegget ga ikke noe informasjon. Det kan være ugyldig.';
$lang['name']                  = 'Navn:';
$lang['date']                  = 'Dato:';
$lang['type']                  = 'Type:';
$lang['desc']                  = 'Beskrivelse:';
$lang['author']                = 'Forfatter:';
$lang['www']                   = 'Nett:';
$lang['error']                 = 'En ukjent feil oppstod.';
$lang['error_download']        = 'Klarte ikke å laste ned tillegget i filen: %s';
$lang['error_badurl']          = 'Mistenker feil URL - klarte ikke å finne filnavnet i URLen';
$lang['error_dircreate']       = 'Klarte ikke å lage en midlertidig mappe for å laste ned';
$lang['error_decompress']      = 'Tilleggsbehandleren klarte ikke å dekomprimere den nedlastede filen. Dette kan være på grunn av en feilet nedlasting, i så fall bør du prøve igjen, eller kompresjonsformatet kan være ukjent, i så fall må du laste ned og installere tillegget manuelt.';
$lang['error_copy']            = 'Det skjedde en feil ved kopiering av en fil under installasjonen av <em>%s</em>: disken kan være full eller rettighetene satt feil. Dette kan ha ført til et delvist installert tillegg og gjort wikien ubrukelig.';
$lang['error_delete']          = 'Det skjedde en feil under forsøket på å slette tillegget <em>%s</em>. Den mest sannsynlige grunnen er utilstrekkelige rettigheter for filene eller mappene.';
$lang['enabled']               = 'Tillegget %s aktivert';
$lang['notenabled']            = 'Plugin %s kunne ikke aktiveres, sjekk filrettighetene.';
$lang['disabled']              = 'Plugin %s deaktivert';
$lang['notdisabled']           = 'Plugin %s kunne ikke deaktiveres, sjekk filrettighetene.';
$lang['packageinstalled']      = 'Installasjonen av tilleggspakka (%d tillegg: %s) var vellykka';
